# eric7.Plugins.PluginWizardSetup

Module implementing the setup.py wizard plug-in.

### Global Attributes

author
autoactivate
className
deactivateable
error
longDescription
name
needsRestart
packageName
pyqtApi
shortDescription
version

### Classes

SetupWizard | Class implementing the setup.py wizard plug-in.

### Functions

None

## SetupWizard

Class implementing the setup.py wizard plug-in.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

SetupWizard | Constructor
__handle | Private method to handle the wizards action.
__initActions | Private method to initialize the actions.
__initMenu | Private method to add the actions to the right menu.
activate | Public method to activate this plug-in.
deactivate | Public method to deactivate this plug-in.

### Static Methods

None

#### SetupWizard (Constructor)

SetupWizard(ui)

Constructor

ui (UI.UserInterface)
  reference to the user interface object

#### SetupWizard.__handle

__handle(category)

Private method to handle the wizards action.

category (str)
  category of setup file to create

#### SetupWizard.__initActions

__initActions()

Private method to initialize the actions.

#### SetupWizard.__initMenu

__initMenu()

Private method to add the actions to the right menu.

#### SetupWizard.activate

activate()

Public method to activate this plug-in.

Return:
  tuple of None and activation status

Return Type:
  tuple of (None, boolean)

#### SetupWizard.deactivate

deactivate()

Public method to deactivate this plug-in.

Up